#!/usr/bin/env node
'use strict'

const fs = require('fs')
const meow = require('meow')
const path = require('path')

const cli = meow(`
  Usage:
    $ mightymite [command] [options]

  Commands:
    build       # Build api from content files
    watch       # Trigger build on file change

  Options
    --src   # Specify content directory
    --out   # Specify output directory
    --config # Specify config file

  Examples
    $ mightymite build --src content --out api
`, {
  flags: {
    src: {
      type: 'string'
    },
    out: {
      type: 'string'
    },
    config: {
      type: 'string'
    }
  }
})

// Show help if no commands are passed
if (!cli.input.length) cli.showHelp()

// Import command
const command = require('../src')[cli.input.shift()]

// Show help if command isn't recognized
if (!command) cli.showHelp()

// If config was passed, use custom config file
if (cli.flags.config) {
  try {
    const config = require(path.join(process.cwd(), cli.flags.config))
    command.apply(null, [ config ])
  } catch (err) {
    console.error(`No config file found at: ${cli.flags.config}`)
  }
} else {
  command.apply(null, cli.input.concat(cli.flags))
}
